@@ -1,7 +1,7 @@
 preferenceRange <- function(s, exact=FALSE)
 {
     if (length(dim(s)) != 2 || ncol(s) != nrow(s))
-        stop("s must be a square matrix")
+        stop("'s' must be a square matrix")
 
     N <- nrow(s)
 
